==> haskell-conduit-1.2.11-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.11
id: conduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW
key: conduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: ec2e252617dfe74fb82876bf9b3b8993
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/conduit-1.2.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/conduit-1.2.11
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/conduit-1.2.11
hs-libraries: HSconduit-1.2.11-LF3u2IjoGXz5B8eRQRwaoW
depends:
    base-4.9.1.0 exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    lifted-base-0.2.3.11-797F0GSRM4GHiCBSQ3AJmQ
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.0-10S0ywqdsCPHnUTlxJLEct
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh
    resourcet-1.1.9-8dcH1R5asu46j8AjnoNKK5 transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.2.11-4-i686.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.2.11
id: conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
key: conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit Data.Conduit.List Data.Conduit.Internal
    Data.Conduit.Lift Data.Conduit.Internal.Fusion
    Data.Conduit.Internal.List.Stream
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit
abi: 4c4f8eab697f2607cc107ea3e0154603
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/conduit-1.2.11
library-dirs: /usr/lib/ghc-8.0.2/site-local/conduit-1.2.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.0.2/conduit-1.2.11
hs-libraries: HSconduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
depends:
    base-4.9.1.0 exceptions-0.8.3-8AMTYj188ri8VOH6LXt0Fd
    lifted-base-0.2.3.11-5HGJGSXUc2GCx17d867zNZ
    mmorph-1.1.0-BKb9vDVN1ubG7npUIlJCzH
    monad-control-1.0.2.1-CGbUZWvNENX5nExoNw6Fw5
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    primitive-0.6.2.0-4578caNkWQ54Gt1mxLF2Yh
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA transformers-0.5.2.0
    transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
